Module parser

Module parser 

Structs

CommentLinkToken
Token representing a link to another item inside the documentation.
MarkdownLink

Enums

DocumentationCommentToken
Generic type for a comment token. It’s either plain content or a link. Notice that the Content token type can store much more than just one word.

Functions

parse_documentation_comment
Parses documentation comment content into a vector of DocumentationCommentTokens, keeping the order in which they were present in the content.