pub struct DocumentationCommentParser<'db> { /* private fields */ }Expand description
Parses plain documentation comments into DocumentationCommentTokens.
Implementations
Sourceimpl<'db> DocumentationCommentParser<'db>
impl<'db> DocumentationCommentParser<'db>
pub fn new(db: &'db dyn Database) -> Self
Sourcepub fn parse_documentation_comment(
&self,
item_id: DocumentableItemId<'db>,
documentation_comment: String,
) -> Vec<DocumentationCommentToken<'db>>
pub fn parse_documentation_comment( &self, item_id: DocumentableItemId<'db>, documentation_comment: String, ) -> Vec<DocumentationCommentToken<'db>>
Parses documentation comment content into vector of DocumentationCommentTokens, keeping the order in which they were present in the content.
We look for 3 types of patterns when it comes to link (ignore the backslash):
“[label](path)”, “[path]” or “[path]”.