pub struct MarkdownLink {
pub link_span: TextSpan,
pub dest_span: Option<TextSpan>,
pub dest_text: Option<String>,
}Fields
link_span: TextSpanThe span of the whole link, including the label, the destination URL and the delimiters.
dest_span: Option<TextSpan>Where the link leads to. Not present when the label could not be resolved.
dest_text: Option<String>The underlying content of dest_span, if present.