pub fn parse_documentation_comment(
documentation_comment: &str,
) -> Vec<DocumentationCommentToken>Expand description
Parses documentation comment content into a vector of DocumentationCommentTokens, keeping the order in which they were present in the content.
We look for 3 link patterns (ignore the backslash):
“[label](path)”, “[path]” or “[path]”.